import java.io.*;

public class GrafLS
{
	static final int MODE_UNCONNECTED = 0;
	static final int MODE_WAITFOR     = 1;
	static final int MODE_CATCHOUTPUT = 2;

	private static void runCommand( String cmd, int mode )
	throws IOException
	{
		Runtime rt = Runtime.getRuntime();
		System.out.println( "Running " + cmd );
		Process pr = rt.exec( cmd );

		if( mode == MODE_WAITFOR )
		{
			System.out.println( "waiting for termination." );
			try
			{
				pr.waitFor();
			}
			catch( InterruptedException e )
			{
				System.out.println( "interrupt: " + e.toString() );
			}
		}
		else if( mode == MODE_CATCHOUTPUT )
		{
			System.out.println( "catching output" );
			BufferedReader procout = new BufferedReader( new InputStreamReader( pr.getInputStream() ) );
			String line;
			
			while( ( line = procout.readLine() ) != null )
			{
				System.out.println( " OUT> " + line );
			}
		}

		try
		{
			System.out.println( " done, return value is: " + pr.exitValue() );
		}
		catch( IllegalThreadStateException e )
		{
			System.out.println( "ok, process is running asynchronously." );
		}
	}

	public static void main( String[] args )
	{
		try
		{
			if( args.length < 1 )
			{
				System.out.println( "usage: java GrafLS [ -waitfor | -catchoutput ] <command>" );
				System.exit( 1 );
			}

			int mode = MODE_UNCONNECTED;
			String cmd = "";
			int i;

			for( i = 0; i < args.length; i++ )
			{
				if( args[i].startsWith( "-" ) )
				{
					if( args[i].equals( "-waitfor" ) )
					{
						mode = MODE_WAITFOR;
					}
					else if( args[i].equals( "-catchoutput" ) )
					{
						mode = MODE_CATCHOUTPUT;
					}
				}
				else
				{
					cmd = args[i];
				}
			}

			runCommand( cmd, mode );
		}
		catch( Exception e )
		{
			System.err.println( e.toString() );
		}
	}
}

